@@ -1,18 +1,47 @@
+"""
+MIT License
+
+Copyright (c) 2023-present Qvco, Konn
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+
 import os
 import time
 import logging
-
 from json import JSONDecodeError
-from typing import Optional, Dict, Any
 
 import httpx
 
-from .login import *
+from .login import get_token
 
-from ..config import *
-from ..errors import *
-from ..responses import *
-from ..utils import *
+from ..config import ErrorType, ErrorMessage
+from ..errors import (
+    HTTPError,
+    BadRequestError,
+    AuthenticationError,
+    ForbiddenError,
+    NotFoundError,
+    RateLimitError,
+    YayServerError,
+)
+from ..utils import Configs, generate_uuid, load_session, save_session, decrypt
 
 
 current_path = os.path.abspath(os.getcwd())
@@ -28,12 +57,13 @@ class API:
         timeout=30,
         err_lang="ja",
         base_path=current_path + "/config/",
-        loglevel_stream=logging.INFO,
-        host=Configs.YAY_PRODUCTION_HOST,
+        save_session=True,
+        loglevel=logging.INFO,
     ):
         self.yaylib_version = Configs.YAYLIB_VERSION
         self.api_version = Configs.YAY_API_VERSION
         self.api_key = Configs.YAY_API_KEY
+        self.fernet = None
         self.secret_key = None
 
         self.proxy = {}
@@ -46,9 +76,9 @@ class API:
         self.timeout = timeout
         self.err_lang = err_lang
         self.base_path = base_path
-        self.host = "https://" + host
+        self.save_session = save_session
 
-        self.generate_all_uuids()
+        self._generate_all_uuids()
         self.session = httpx.Client(proxies=self.proxy, timeout=self.timeout)
         self.session.headers.update(Configs.REQUEST_HEADERS)
         self.session.headers.update({"X-Device-Uuid": self.device_uuid})
@@ -61,7 +91,7 @@ class API:
             os.makedirs(base_path)
 
         ch = logging.StreamHandler()
-        ch.setLevel(loglevel_stream)
+        ch.setLevel(loglevel)
         ch.setFormatter(logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 
         handler_existed = False
@@ -75,12 +105,21 @@ class API:
 
         self.logger.info("yaylib version: " + self.yaylib_version + " started")
 
-    def request(
-        self, method, endpoint, params=None, payload=None, user_auth=True, headers=None
+    def _request(
+        self,
+        method,
+        endpoint,
+        params=None,
+        payload=None,
+        user_auth=True,
+        headers=None,
+        access_token=None,
     ):
         headers = headers or self.session.headers
 
-        if not user_auth:
+        if access_token is not None:
+            headers["Authorization"] = f"Bearer {access_token}"
+        elif not user_auth and "Authorization" in headers:
             del headers["Authorization"]
 
         response = None
@@ -103,7 +142,7 @@ class API:
                 method, endpoint, params=params, json=payload, headers=headers
             )
 
-            if response.status_code == 401:
+            if self.save_session is True and response.status_code == 401:
                 if "/api/v1/oauth/token" in endpoint:
                     os.remove(self.base_path + "credentials.json")
                     message = "Refresh token expired. Try logging in again."
@@ -113,20 +152,24 @@ class API:
                 self.logger.debug("Access token expired. Refreshing tokens...")
 
                 if auth_retry_count < max_auth_retries:
-                    credentials = load_credentials(self)
+                    credentials = load_session(base_path=self.base_path)
 
-                    if credentials is not None:
+                    if credentials is not None and self.fernet is not None:
+                        credentials = decrypt(
+                            fernet=self.fernet, credentials=credentials
+                        )
                         refresh_token = credentials["refresh_token"]
                         response = get_token(
                             self,
                             grant_type="refresh_token",
                             refresh_token=refresh_token,
                         )
-                        save_credentials(
-                            self,
-                            response.access_token,
-                            response.refresh_token,
-                            response.user_id,
+                        save_session(
+                            base_path=self.base_path,
+                            fernet=self.fernet,
+                            access_token=response.access_token,
+                            refresh_token=response.refresh_token,
+                            user_id=response.user_id,
                         )
                         self.session.headers[
                             "Authorization"
@@ -164,11 +207,11 @@ class API:
         )
 
         try:
-            json_response = response.json()
+            formatted_response = response.json()
         except JSONDecodeError:
-            return response.text
+            formatted_response = response.text
 
-        return self._handle_response(response, json_response)
+        return self._handle_response(response, formatted_response)
 
     def _make_request(
         self,
@@ -179,13 +222,17 @@ class API:
         data_type=None,
         user_auth=True,
         headers=None,
+        access_token=None,
     ):
-        response = self.request(method, endpoint, params, payload, user_auth, headers)
+        response = self._request(
+            method, endpoint, params, payload, user_auth, headers, access_token
+        )
         if data_type:
             return self._construct_response(response, data_type)
         return response
 
-    def _construct_response(self, data, data_type):
+    @staticmethod
+    def _construct_response(data, data_type):
         if data_type is not None:
             if isinstance(data, list):
                 data = [data_type(result) for result in data]
@@ -193,13 +240,16 @@ class API:
                 data = data_type(data)
         return data
 
-    def _check_authorization(self) -> None:
-        if self.session.headers.get("Authorization") is None:
+    def _check_authorization(self, access_token) -> None:
+        if self.session.headers.get("Authorization") is None and access_token is None:
             message = "Authorization is not present in the header."
             raise AuthenticationError(message)
 
-    def _handle_response(self, response, json_response):
-        translated_response = self.translate_error_message(json_response)
+    def _handle_response(self, response, formatted_response):
+        translated_response = formatted_response
+        if isinstance(formatted_response, dict):
+            translated_response = self._translate_error_message(formatted_response)
+
         if response.status_code == 400:
             raise BadRequestError(translated_response)
         if response.status_code == 401:
@@ -214,9 +264,9 @@ class API:
             raise YayServerError(translated_response)
         if response.status_code and not 200 <= response.status_code < 300:
             raise HTTPError(translated_response)
-        return json_response
+        return formatted_response
 
-    def translate_error_message(self, response):
+    def _translate_error_message(self, response):
         if self.err_lang == "ja":
             try:
                 error_code = response.get("error_code", None)
@@ -231,6 +281,6 @@ class API:
         else:
             return response
 
-    def generate_all_uuids(self):
+    def _generate_all_uuids(self):
         self.device_uuid = generate_uuid()[0]
         self.uuid, self.url_uuid = generate_uuid()
