@@ -1,49 +1,89 @@
-from datetime import datetime
-from typing import Dict, List
+"""
+MIT License
 
-from ..config import *
-from ..errors import *
-from ..models import *
-from ..responses import *
-from ..utils import *
+Copyright (c) 2023-present Qvco, Konn
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+
+from typing import List
+
+from ..config import Endpoints
+from ..models import Bgm, ConferenceCall, Post
+from ..responses import (
+    BgmsResponse,
+    CallStatusResponse,
+    ConferenceCallResponse,
+    GamesResponse,
+    GenresResponse,
+    PostResponse,
+    PostsResponse,
+    UsersByTimestampResponse,
+)
 
 
-def bump_call(self, call_id: int, participant_limit: int = None):
+def bump_call(
+    self, call_id: int, participant_limit: int = None, access_token: str = None
+):
     params = {}
     if participant_limit:
         params["participant_limit"] = participant_limit
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.CALLS_V1}/{call_id}/bump", params=params
+        "POST",
+        endpoint=f"{Endpoints.CALLS_V1}/{call_id}/bump",
+        params=params,
+        access_token=access_token,
     )
     self.logger.info("Call bumped.")
     return response
 
 
-def get_user_active_call(self, user_id: int) -> Post:
+def get_user_active_call(self, user_id: int, access_token: str = None) -> Post:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.POSTS_V1}/active_call",
         params={"user_id": user_id},
         data_type=PostResponse,
+        access_token=access_token,
     ).post
 
 
-def get_bgms(self) -> List[Bgm]:
+def get_bgms(self, access_token: str = None) -> List[Bgm]:
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.CALLS_V1}/bgm", data_type=BgmsResponse
+        "GET",
+        endpoint=f"{Endpoints.CALLS_V1}/bgm",
+        data_type=BgmsResponse,
+        access_token=access_token,
     ).bgm
 
 
-def get_call(self, call_id: int) -> ConferenceCall:
+def get_call(self, call_id: int, access_token: str = None) -> ConferenceCall:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.CALLS_V1}/conferences/{call_id}",
         data_type=ConferenceCallResponse,
+        access_token=access_token,
     ).conference_call
 
 
 def get_call_invitable_users(
-    self, call_id: int, from_timestamp: int = None
+    self, call_id: int, from_timestamp: int = None, access_token: str = None
 ) -> UsersByTimestampResponse:
     # @Nullable @Query("user[nickname]")
     params = {}
@@ -54,18 +94,22 @@ def get_call_invitable_users(
         endpoint=f"{Endpoints.CALLS_V1}/{call_id}/users/invitable",
         params=params,
         data_type=UsersByTimestampResponse,
+        access_token=access_token,
     )
 
 
-def get_call_status(self, opponent_id: int) -> CallStatusResponse:
+def get_call_status(
+    self, opponent_id: int, access_token: str = None
+) -> CallStatusResponse:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.CALLS_V1}/phone_status/{opponent_id}",
         data_type=CallStatusResponse,
+        access_token=access_token,
     )
 
 
-def get_games(self, **params) -> GamesResponse:
+def get_games(self, access_token: str = None, **params) -> GamesResponse:
     """
 
     Parameters
@@ -80,10 +124,11 @@ def get_games(self, **params) -> GamesResponse:
         endpoint=f"{Endpoints.GAMES_V1}/apps",
         params=params,
         data_type=GamesResponse,
+        access_token=access_token,
     )
 
 
-def get_genres(self, **params) -> GenresResponse:
+def get_genres(self, access_token: str = None, **params) -> GenresResponse:
     """
 
     Parameters
@@ -97,10 +142,11 @@ def get_genres(self, **params) -> GenresResponse:
         endpoint=f"{Endpoints.GENRES_V1}",
         params=params,
         data_type=GenresResponse,
+        access_token=access_token,
     )
 
 
-def get_group_calls(self, **params) -> PostsResponse:
+def get_group_calls(self, access_token: str = None, **params) -> PostsResponse:
     """
 
     Parameters
@@ -116,10 +162,13 @@ def get_group_calls(self, **params) -> PostsResponse:
         endpoint=f"{Endpoints.POSTS_V1}/group_calls",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def invite_to_call_bulk(self, call_id: int, group_id: int = None):
+def invite_to_call_bulk(
+    self, call_id: int, group_id: int = None, access_token: str = None
+):
     """
 
     Parameters
@@ -132,13 +181,18 @@ def invite_to_call_bulk(self, call_id: int, group_id: int = None):
     if group_id:
         params["group_id"] = group_id
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.CALLS_V1}/{call_id}/bulk_invite", params=params
+        "POST",
+        endpoint=f"{Endpoints.CALLS_V1}/{call_id}/bulk_invite",
+        params=params,
+        access_token=access_token,
     )
     self.logger.info("Invited your online followings to the call.")
     return response
 
 
-def invite_users_to_call(self, call_id: int, user_ids: List[int]):
+def invite_users_to_call(
+    self, call_id: int, user_ids: List[int], access_token: str = None
+):
     """
 
     Parameters
@@ -151,12 +205,15 @@ def invite_users_to_call(self, call_id: int, user_ids: List[int]):
         "POST",
         endpoint=f"{Endpoints.CALLS_V1}/conference_calls/{call_id}/invite",
         payload={"call_id": call_id, "user_ids[]": user_ids},
+        access_token=access_token,
     )
     self.logger.info("Invited users to call.")
     return response
 
 
-def invite_users_to_chat_call(self, chat_room_id: int, room_id: int, room_url: str):
+def invite_users_to_chat_call(
+    self, chat_room_id: int, room_id: int, room_url: str, access_token: str = None
+):
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.CALLS_V2}/invite",
@@ -165,16 +222,18 @@ def invite_users_to_chat_call(self, chat_room_id: int, room_id: int, room_url: s
             "room_id": room_id,
             "room_url": room_url,
         },
+        access_token=access_token,
     )
     self.logger.info("Invited users to chat call.")
     return response
 
 
-def kick_and_ban_from_call(self, call_id: int, user_id: int):
+def kick_and_ban_from_call(self, call_id: int, user_id: int, access_token: str = None):
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.CALLS_V1}/conference_calls/{call_id}/kick",
         payload={"user_id": user_id},
+        access_token=access_token,
     )
     self.logger.info("User has been banned from the call.")
     return response
@@ -186,6 +245,7 @@ def set_call(
     joinable_by: str,
     game_title: str = None,
     category_id: str = None,
+    access_token: str = None,
 ):
     response = self._make_request(
         "PUT",
@@ -195,37 +255,45 @@ def set_call(
             "game_title": game_title,
             "category_id": category_id,
         },
+        access_token=access_token,
     )
     self.logger.info("Started a call")
     return response
 
 
-def set_user_role(self, call_id: int, user_id: int, role: str):
+def set_user_role(
+    self, call_id: int, user_id: int, role: str, access_token: str = None
+):
     response = self._make_request(
         "PUT",
         endpoint=f"{Endpoints.CALLS_V1}/{call_id}/users/{user_id}",
         payload={"role": role},
+        access_token=access_token,
     )
     self.logger.info(f"User '{user_id}' has been given a role.")
     return response
 
 
-def start_call(self, conference_id: int, call_sid: str = None) -> ConferenceCall:
+def start_call(
+    self, conference_id: int, call_sid: str = None, access_token: str = None
+) -> ConferenceCall:
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.CALLS_V1}/start_conference_call",
         payload={"conference_id": conference_id, "call_sid": call_sid},
         data_type=ConferenceCallResponse,
+        access_token=access_token,
     ).conference_call
     self.logger.info("Joined the call.")
     return response
 
 
-def stop_call(self, conference_id: int, call_sid: str = None):
+def stop_call(self, conference_id: int, call_sid: str = None, access_token: str = None):
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.CALLS_V1}/leave_conference_call",
         payload={"conference_id": conference_id, "call_sid": call_sid},
+        access_token=access_token,
     )
     self.logger.info("Left the call.")
     return response
