@@ -1,35 +1,74 @@
+"""
+MIT License
+
+Copyright (c) 2023-present Qvco, Konn
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+
 import json
 from datetime import datetime
 from typing import Union, Dict, List
 
-from ..config import *
-from ..errors import *
-from ..models import *
-from ..responses import *
-from ..utils import *
+from ..config import Endpoints
+from ..errors import ForbiddenError, NotFoundError
+from ..models import ConferenceCall, Post, SharedUrl, Survey
+from ..responses import (
+    BookmarkPostResponse,
+    CreatePostResponse,
+    PostResponse,
+    PostsResponse,
+    PostLikersResponse,
+    PostTagsResponse,
+    LikePostsResponse,
+    ValidationPostResponse,
+)
+from ..utils import signed_info_calculating
 
 
-def add_bookmark(self, user_id: int, post_id: int) -> BookmarkPostResponse:
-    self._check_authorization()
+def add_bookmark(
+    self, user_id: int, post_id: int, access_token: str = None
+) -> BookmarkPostResponse:
+    self._check_authorization(access_token)
     response = self._make_request(
         "PUT",
         endpoint=f"{Endpoints.USERS_V1}/{user_id}/bookmarks/{post_id}",
         data_type=BookmarkPostResponse,
+        access_token=access_token,
     )
     self.logger.info("Post has been added to the bookmarks.")
     return response
 
 
-def add_group_highlight_post(self, group_id: int, post_id: int):
+def add_group_highlight_post(
+    self, group_id: int, post_id: int, access_token: str = None
+):
     """
 
     投稿をグループのまとめに追加します
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     response = self._make_request(
         "PUT",
         endpoint=f"{Endpoints.GROUPS_V1}/{group_id}/highlights/{post_id}",
+        access_token=access_token,
     )
     self.logger.info("Post has been added to the group highlight.")
     return response
@@ -55,8 +94,9 @@ def create_call_post(
     attachment_7_filename: str = None,
     attachment_8_filename: str = None,
     attachment_9_filename: str = None,
+    access_token: str = None,
 ) -> ConferenceCall:
-    self._check_authorization()
+    self._check_authorization(access_token)
 
     if text is not None:
         if "@:start:" in text and ":end:" in text:
@@ -92,26 +132,31 @@ def create_call_post(
             "attachment_9_filename": attachment_9_filename,
         },
         data_type=CreatePostResponse,
+        access_token=access_token,
     ).conference_call
     self.logger.info("Call post has been created.")
     return response
 
 
-def create_group_pin_post(self, post_id: int, group_id: int):
-    self._check_authorization()
+def create_group_pin_post(self, post_id: int, group_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "PUT",
         endpoint=f"{Endpoints.POSTS_V2}/group_pinned_post",
         payload={"post_id": post_id, "group_id": group_id},
+        access_token=access_token,
     )
     self.logger.info("Pinned the post in the group.")
     return response
 
 
-def create_pin_post(self, post_id: int):
-    self._check_authorization()
+def create_pin_post(self, post_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.PINNED_V1}/posts", payload={"id": post_id}
+        "POST",
+        endpoint=f"{Endpoints.PINNED_V1}/posts",
+        payload={"id": post_id},
+        access_token=access_token,
     )
     self.logger.info("Pinned post.")
     return response
@@ -193,10 +238,11 @@ def create_post(
     attachment_8_filename: str = None,
     attachment_9_filename: str = None,
     video_file_name: str = None,
+    access_token: str = None,
 ) -> Post:
-    self._check_authorization()
+    self._check_authorization(access_token)
     headers = self.session.headers
-    headers["X-Jwt"] = self.get_web_socket_token()
+    headers["X-Jwt"] = self.get_web_socket_token(access_token=access_token)
 
     if text is not None:
         if "@:start:" in text and ":end:" in text:
@@ -216,7 +262,9 @@ def create_post(
 
     if shared_url is not None:
         try:
-            shared_url = self.get_url_metadata(url=shared_url).data
+            shared_url = self.get_url_metadata(
+                url=shared_url, access_token=access_token
+            ).data
         except ForbiddenError:
             self.logger.error("Unable to get the URL metadata")
             shared_url = None
@@ -248,6 +296,7 @@ def create_post(
         },
         data_type=Post,
         headers=headers,
+        access_token=access_token,
     )
     self.logger.info("Post has been created.")
     return response
@@ -275,10 +324,11 @@ def create_repost(
     attachment_8_filename: str = None,
     attachment_9_filename: str = None,
     video_file_name: str = None,
+    access_token: str = None,
 ) -> Post:
-    self._check_authorization()
+    self._check_authorization(access_token)
     headers = self.session.headers
-    headers["X-Jwt"] = self.get_web_socket_token()
+    headers["X-Jwt"] = self.get_web_socket_token(access_token=access_token)
 
     if text is not None:
         if "@:start:" in text and ":end:" in text:
@@ -298,7 +348,9 @@ def create_repost(
 
     if shared_url is not None:
         try:
-            shared_url = self.get_url_metadata(url=shared_url).data
+            shared_url = self.get_url_metadata(
+                url=shared_url, access_token=access_token
+            ).data
         except ForbiddenError:
             self.logger.error("Unable to get the URL metadata")
             shared_url = None
@@ -331,6 +383,7 @@ def create_repost(
         },
         data_type=CreatePostResponse,
         headers=headers,
+        access_token=access_token,
     ).post
     self.logger.info("Repost has been created.")
     return response
@@ -344,8 +397,9 @@ def create_share_post(
     font_size: int = None,
     color: int = None,
     group_id: int = None,
+    access_token: str = None,
 ) -> Post:
-    self._check_authorization()
+    self._check_authorization(access_token)
     timestamp = int(datetime.now().timestamp())
     response = self._make_request(
         "POST",
@@ -363,6 +417,7 @@ def create_share_post(
             "signed_info": signed_info_calculating(self.device_uuid, timestamp),
         },
         data_type=Post,
+        access_token=access_token,
     )
     self.logger.info("Share post has been created.")
     return response
@@ -390,10 +445,11 @@ def create_thread_post(
     attachment_8_filename: str = None,
     attachment_9_filename: str = None,
     video_file_name: str = None,
+    access_token: str = None,
 ) -> Post:
-    self._check_authorization()
+    self._check_authorization(access_token)
     headers = self.session.headers
-    headers["X-Jwt"] = self.get_web_socket_token()
+    headers["X-Jwt"] = self.get_web_socket_token(access_token=access_token)
 
     if text is not None:
         if "@:start:" in text and ":end:" in text:
@@ -413,7 +469,9 @@ def create_thread_post(
 
     if shared_url is not None:
         try:
-            shared_url = self.get_url_metadata(url=shared_url).data
+            shared_url = self.get_url_metadata(
+                url=shared_url, access_token=access_token
+            ).data
         except ForbiddenError:
             self.logger.error("Unable to get the URL metadata")
             shared_url = None
@@ -446,17 +504,19 @@ def create_thread_post(
         },
         data_type=Post,
         headers=headers,
+        access_token=access_token,
     )
     self.logger.info("Thread post has been created.")
     return response
 
 
-def delete_all_post(self):
-    self._check_authorization()
+def delete_all_post(self, access_token: str = None):
+    self._check_authorization(access_token)
     try:
         response = self._make_request(
             "POST",
             endpoint=f"{Endpoints.POSTS_V1}/delete_all_post",
+            access_token=access_token,
         )
         self.logger.info("Post deletion request has been sent.")
         return response
@@ -464,28 +524,33 @@ def delete_all_post(self):
         self.logger.info("Post not found. Skipping...")
 
 
-def delete_group_pin_post(self, group_id: int):
-    self._check_authorization()
+def delete_group_pin_post(self, group_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "DELETE",
         endpoint=f"{Endpoints.POSTS_V2}/group_pinned_post",
         payload={"group_id": group_id},
+        access_token=access_token,
     )
     self.logger.info("Unpinned post in the group.")
     return response
 
 
-def delete_pin_post(self, post_id: int):
-    self._check_authorization()
+def delete_pin_post(self, post_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "DELETE", endpoint=f"{Endpoints.PINNED_V1}/posts/{post_id}"
+        "DELETE",
+        endpoint=f"{Endpoints.PINNED_V1}/posts/{post_id}",
+        access_token=access_token,
     )
     self.logger.info("Unpinned post.")
     return response
 
 
-def get_bookmark(self, user_id: int, from_str: str = None) -> PostsResponse:
-    self._check_authorization()
+def get_bookmark(
+    self, user_id: int, from_str: str = None, access_token: str = None
+) -> PostsResponse:
+    self._check_authorization(access_token)
     params = {}
     if from_str:
         params = {"from": from_str}
@@ -494,10 +559,11 @@ def get_bookmark(self, user_id: int, from_str: str = None) -> PostsResponse:
         endpoint=f"{Endpoints.USERS_V1}/{user_id}/bookmarks",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_timeline_calls(self, **params) -> PostsResponse:
+def get_timeline_calls(self, access_token: str = None, **params) -> PostsResponse:
     """
 
     Parameters:
@@ -519,10 +585,13 @@ def get_timeline_calls(self, **params) -> PostsResponse:
         endpoint=f"{Endpoints.POSTS_V2}/call_timeline",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_conversation(self, conversation_id: int, **params) -> PostsResponse:
+def get_conversation(
+    self, conversation_id: int, access_token: str = None, **params
+) -> PostsResponse:
     """
 
     Parameters:
@@ -541,19 +610,25 @@ def get_conversation(self, conversation_id: int, **params) -> PostsResponse:
         endpoint=f"{Endpoints.CONVERSATIONS_V2}/{conversation_id}",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_conversation_root_posts(self, post_ids: List[int]) -> PostsResponse:
+def get_conversation_root_posts(
+    self, post_ids: List[int], access_token: str = None
+) -> PostsResponse:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.CONVERSATIONS_V2}/root_posts",
         params={"ids[]": post_ids},
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_following_call_timeline(self, **params) -> PostsResponse:
+def get_following_call_timeline(
+    self, access_token: str = None, **params
+) -> PostsResponse:
     """
 
     Parameters:
@@ -567,16 +642,17 @@ def get_following_call_timeline(self, **params) -> PostsResponse:
         - exclude_recent_gomimushi: bool = None
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.POSTS_V2}/call_followers_timeline",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_following_timeline(self, **params) -> PostsResponse:
+def get_following_timeline(self, access_token: str = None, **params) -> PostsResponse:
     """
 
     Parameters:
@@ -591,16 +667,19 @@ def get_following_timeline(self, **params) -> PostsResponse:
         - custom_generation_range: bool = None
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.POSTS_V2}/following_timeline",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_group_highlight_posts(self, group_id: int, **params) -> PostsResponse:
+def get_group_highlight_posts(
+    self, group_id: int, access_token: str = None, **params
+) -> PostsResponse:
     """
 
     グループのまとめ投稿を取得します
@@ -618,11 +697,12 @@ def get_group_highlight_posts(self, group_id: int, **params) -> PostsResponse:
         endpoint=f"{Endpoints.GROUPS_V1}/{group_id}/highlights",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
 def get_group_timeline_by_keyword(
-    self, group_id: int, keyword: str, **params
+    self, group_id: int, keyword: str, access_token: str = None, **params
 ) -> PostsResponse:
     """
 
@@ -642,10 +722,13 @@ def get_group_timeline_by_keyword(
         endpoint=f"{Endpoints.GROUPS_V2}/{group_id}/posts/search",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_group_timeline(self, group_id: int, **params) -> PostsResponse:
+def get_group_timeline(
+    self, group_id: int, access_token: str = None, **params
+) -> PostsResponse:
     """
 
     Parameters:
@@ -665,10 +748,13 @@ def get_group_timeline(self, group_id: int, **params) -> PostsResponse:
         endpoint=f"{Endpoints.POSTS_V2}/group_timeline",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_timeline_by_hashtag(self, hashtag: str, **params) -> PostsResponse:
+def get_timeline_by_hashtag(
+    self, hashtag: str, access_token: str = None, **params
+) -> PostsResponse:
     """
 
     Parameters:
@@ -684,10 +770,11 @@ def get_timeline_by_hashtag(self, hashtag: str, **params) -> PostsResponse:
         endpoint=f"{Endpoints.POSTS_V2}/tags/{hashtag}",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_my_posts(self, **params) -> PostsResponse:
+def get_my_posts(self, access_token: str = None, **params) -> PostsResponse:
     """
 
     Parameters:
@@ -698,22 +785,28 @@ def get_my_posts(self, **params) -> PostsResponse:
         - include_group_post: bool - (optional)
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.POSTS_V2}/mine",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_post(self, post_id: int) -> Post:
+def get_post(self, post_id: int, access_token: str = None) -> Post:
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.POSTS_V2}/{post_id}", data_type=PostResponse
+        "GET",
+        endpoint=f"{Endpoints.POSTS_V2}/{post_id}",
+        data_type=PostResponse,
+        access_token=access_token,
     ).post
 
 
-def get_post_likers(self, post_id: int, **params) -> PostLikersResponse:
+def get_post_likers(
+    self, post_id: int, access_token: str = None, **params
+) -> PostLikersResponse:
     """
 
     Parameters:
@@ -728,10 +821,13 @@ def get_post_likers(self, post_id: int, **params) -> PostLikersResponse:
         endpoint=f"{Endpoints.POSTS_V1}/{post_id}/likers",
         params=params,
         data_type=PostLikersResponse,
+        access_token=access_token,
     )
 
 
-def get_post_reposts(self, post_id: int, **params: int) -> PostsResponse:
+def get_post_reposts(
+    self, post_id: int, access_token: str = None, **params: int
+) -> PostsResponse:
     """
 
     Parameters:
@@ -747,30 +843,33 @@ def get_post_reposts(self, post_id: int, **params: int) -> PostsResponse:
         endpoint=f"{Endpoints.POSTS_V2}/{post_id}/reposts",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_posts(self, post_ids: List[int]) -> PostsResponse:
+def get_posts(self, post_ids: List[int], access_token: str = None) -> PostsResponse:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.POSTS_V2}/multiple",
         params={"post_ids[]": post_ids},
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
 def get_recommended_post_tags(
-    self, tag: str = None, save_recent_search: bool = False
+    self, tag: str = None, save_recent_search: bool = False, access_token: str = None
 ) -> PostTagsResponse:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.POSTS_V1}/recommended_tag",
         payload={"tag": tag, "save_recent_search": save_recent_search},
         data_type=PostTagsResponse,
+        access_token=access_token,
     )
 
 
-def get_recommended_posts(self, **params) -> PostsResponse:
+def get_recommended_posts(self, access_token: str = None, **params) -> PostsResponse:
     """
 
     Parameters:
@@ -786,10 +885,13 @@ def get_recommended_posts(self, **params) -> PostsResponse:
         endpoint=f"{Endpoints.POSTS_V2}/recommended_timeline",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_timeline_by_keyword(self, keyword: str = None, **params) -> PostsResponse:
+def get_timeline_by_keyword(
+    self, keyword: str = None, access_token: str = None, **params
+) -> PostsResponse:
     """
 
     Parameters:
@@ -806,10 +908,13 @@ def get_timeline_by_keyword(self, keyword: str = None, **params) -> PostsRespons
         endpoint=f"{Endpoints.POSTS_V2}/search",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_timeline(self, **params: int | str | bool) -> PostsResponse:
+def get_timeline(
+    self, access_token: str = None, **params: int | str | bool
+) -> PostsResponse:
     # - from: str - (optional)
     """
 
@@ -831,23 +936,30 @@ def get_timeline(self, **params: int | str | bool) -> PostsResponse:
     """
     endpoint = f"{Endpoints.POSTS_V2}/timeline"
     if "noreply_mode" in params and params["noreply_mode"] is True:
-        self._check_authorization()
+        self._check_authorization(access_token)
         endpoint = f"{Endpoints.POSTS_V2}/noreply_timeline"
     return self._make_request(
-        "GET", endpoint=endpoint, params=params, data_type=PostsResponse
+        "GET",
+        endpoint=endpoint,
+        params=params,
+        data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def get_url_metadata(self, url: str) -> SharedUrl:
+def get_url_metadata(self, url: str, access_token: str = None) -> SharedUrl:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.POSTS_V2}/url_metadata",
         params={"url": url},
         data_type=SharedUrl,
+        access_token=access_token,
     )
 
 
-def get_user_timeline(self, user_id: int, **params) -> PostsResponse:
+def get_user_timeline(
+    self, user_id: int, access_token: str = None, **params
+) -> PostsResponse:
     """
 
     Parameters:
@@ -864,47 +976,56 @@ def get_user_timeline(self, user_id: int, **params) -> PostsResponse:
         endpoint=f"{Endpoints.POSTS_V2}/user_timeline",
         params=params,
         data_type=PostsResponse,
+        access_token=access_token,
     )
 
 
-def like_posts(self, post_ids: List[int]) -> LikePostsResponse:
-    self._check_authorization()
+def like_posts(
+    self, post_ids: List[int], access_token: str = None
+) -> LikePostsResponse:
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.POSTS_V2}/like",
         payload={"post_ids": post_ids},
         data_type=LikePostsResponse,
+        access_token=access_token,
     )
     self.logger.info("Posts have been liked.")
     return response
 
 
-def remove_bookmark(self, user_id: int, post_id: int):
-    self._check_authorization()
+def remove_bookmark(self, user_id: int, post_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "DELETE",
         endpoint=f"{Endpoints.USERS_V1}/{user_id}/bookmarks/{post_id}",
+        access_token=access_token,
     )
     self.logger.info("Bookmark has been removed.")
     return response
 
 
-def remove_group_highlight_post(self, group_id: int, post_id: int):
-    self._check_authorization()
+def remove_group_highlight_post(
+    self, group_id: int, post_id: int, access_token: str = None
+):
+    self._check_authorization(access_token)
     response = self._make_request(
         "DELETE",
         endpoint=f"{Endpoints.GROUPS_V1}/{group_id}/highlights/{post_id}",
+        access_token=access_token,
     )
     self.logger.info("Group hightlight post removed.")
     return response
 
 
-def remove_posts(self, post_ids: List[int]):
-    self._check_authorization()
+def remove_posts(self, post_ids: List[int], access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.POSTS_V2}/mass_destroy",
         payload={"posts_ids": post_ids},
+        access_token=access_token,
     )
     self.logger.info("Posts have been removed.")
     return response
@@ -920,8 +1041,9 @@ def report_post(
     screenshot_2_filename: str = None,
     screenshot_3_filename: str = None,
     screenshot_4_filename: str = None,
+    access_token: str = None,
 ):
-    self._check_authorization()
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.POSTS_V3}/{post_id}/report",
@@ -934,16 +1056,18 @@ def report_post(
             "screenshot_3_filename": screenshot_3_filename,
             "screenshot_4_filename": screenshot_4_filename,
         },
+        access_token=access_token,
     )
     self.logger.info("Post has been reported.")
     return response
 
 
-def unlike_post(self, post_id: int):
-    self._check_authorization()
+def unlike_post(self, post_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.POSTS_V1}/{post_id}/unlike",
+        access_token=access_token,
     )
     self.logger.info("Post has been unliked.")
     return response
@@ -956,8 +1080,9 @@ def update_post(
     font_size: int = None,
     color: int = None,
     message_tags: str = "[]",
+    access_token: str = None,
 ) -> Post:
-    self._check_authorization()
+    self._check_authorization(access_token)
 
     if "@:start:" in text and ":end:" in text:
         text, message_tags = parse_mention_format(self, text)
@@ -976,26 +1101,32 @@ def update_post(
             "timestamp": timestamp,
             "signed_info": signed_info_calculating(self.device_uuid, timestamp),
         },
+        access_token=access_token,
     )
     self.logger.info("Post has been updated.")
     return response
 
 
-def view_video(self, video_id: int):
+def view_video(self, video_id: int, access_token: str = None):
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.POSTS_V1}/videos/{video_id}/view"
+        "POST",
+        endpoint=f"{Endpoints.POSTS_V1}/videos/{video_id}/view",
+        access_token=access_token,
     )
     self.logger.info("Viewed the video.")
     return response
 
 
-def vote_survey(self, survey_id: int, choice_id: int) -> Survey:
-    self._check_authorization()
+def vote_survey(
+    self, survey_id: int, choice_id: int, access_token: str = None
+) -> Survey:
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.SURVEYS_V2}/{survey_id}/vote",
         payload={"choice_id": choice_id},
         data_type=ValidationPostResponse,
+        access_token=access_token,
     ).survey
     self.logger.info("Voted.")
     return response
