@@ -1,24 +1,69 @@
+"""
+MIT License
+
+Copyright (c) 2023-present Qvco, Konn
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+
 from datetime import datetime
-from typing import Union, Dict, List
+from typing import Union, List
 
-from ..config import *
-from ..errors import *
-from ..models import *
-from ..responses import *
-from ..utils import *
+from ..config import Configs, Endpoints
+from ..models import Footprint, User, UserWrapper
+from ..responses import (
+    ActiveFollowingsResponse,
+    BlockedUserIdsResponse,
+    BlockedUsersResponse,
+    CreatePostResponse,
+    CreateUserResponse,
+    FollowRecommendationsResponse,
+    FollowRequestCountResponse,
+    FollowUsersResponse,
+    FootprintsResponse,
+    HiddenResponse,
+    RefreshCounterRequestsResponse,
+    SocialShareUsersResponse,
+    UserResponse,
+    UsersResponse,
+    RankingUsersResponse,
+    UserEmailResponse,
+    HimaUsersResponse,
+    UsersByTimestampResponse,
+    UserTimestampResponse,
+)
+from ..utils import signed_info_calculating, signed_version_calculating
 
 
-def delete_footprint(self, user_id: int, footprint_id: int):
-    self._check_authorization()
+def delete_footprint(self, user_id: int, footprint_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "DELETE", endpoint=f"{Endpoints.USERS_V2}/{user_id}/footprints/{footprint_id}"
+        "DELETE",
+        endpoint=f"{Endpoints.USERS_V2}/{user_id}/footprints/{footprint_id}",
+        access_token=access_token,
     )
     self.logger.info("Footprint has been deleted.")
     return response
 
 
-def destroy_user(self):
-    self._check_authorization()
+def destroy_user(self, access_token: str = None):
+    self._check_authorization(access_token)
     answer = input("Are you sure you want to delete your account? Y/N")
     if answer.lower() != "y":
         return
@@ -32,30 +77,38 @@ def destroy_user(self):
             "timestamp": timestamp,
             "signed_info": signed_info_calculating(self.device_uuid, timestamp),
         },
+        access_token=access_token,
     )
     self.logger.info("User has been deleted.")
     return response
 
 
-def follow_user(self, user_id: int):
-    self._check_authorization()
+def follow_user(self, user_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.USERS_V2}/{user_id}/follow"
+        "POST",
+        endpoint=f"{Endpoints.USERS_V2}/{user_id}/follow",
+        access_token=access_token,
     )
-    self.logger.info("Followed the user '{user_id}'.")
+    self.logger.info(f"Followed the user '{user_id}'.")
     return response
 
 
-def follow_users(self, user_ids: List[int]):
-    self._check_authorization()
+def follow_users(self, user_ids: List[int], access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.USERS_V2}/follow", params={"user_ids[]": user_ids}
+        "POST",
+        endpoint=f"{Endpoints.USERS_V2}/follow",
+        params={"user_ids[]": user_ids},
+        access_token=access_token,
     )
     self.logger.info("Followed multiple users.")
     return response
 
 
-def get_active_followings(self, **params) -> ActiveFollowingsResponse:
+def get_active_followings(
+    self, access_token: str = None, **params
+) -> ActiveFollowingsResponse:
     """
 
     Parameters:
@@ -65,16 +118,19 @@ def get_active_followings(self, **params) -> ActiveFollowingsResponse:
         - from_loggedin_at: int = None
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V1}/active_followings",
         params=params,
         data_type=ActiveFollowingsResponse,
+        access_token=access_token,
     )
 
 
-def get_follow_recommendations(self, **params) -> FollowRecommendationsResponse:
+def get_follow_recommendations(
+    self, access_token: str = None, **params
+) -> FollowRecommendationsResponse:
     """
 
     Parameters:
@@ -85,51 +141,59 @@ def get_follow_recommendations(self, **params) -> FollowRecommendationsResponse:
         - sources: List[str] = None
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.FRIENDS_V1}",
         params=params,
         data_type=FollowRecommendationsResponse,
+        access_token=access_token,
     )
 
 
-def get_follow_request(self, from_timestamp: int = None) -> UsersByTimestampResponse:
+def get_follow_request(
+    self, from_timestamp: int = None, access_token: str = None
+) -> UsersByTimestampResponse:
     params = {}
     if from_timestamp:
         params["from_timestamp"] = from_timestamp
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V2}/follow_requests",
         params=params,
         data_type=UsersByTimestampResponse,
+        access_token=access_token,
     )
 
 
-def get_follow_request_count(self) -> int:
-    self._check_authorization()
+def get_follow_request_count(self, access_token: str = None) -> int:
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V2}/follow_requests_count",
         data_type=FollowRequestCountResponse,
+        access_token=access_token,
     ).users_count
 
 
-def get_following_users_born(self, birthdate: int = None) -> UsersResponse:
+def get_following_users_born(
+    self, birthdate: int = None, access_token: str = None
+) -> UsersResponse:
     params = {}
     if birthdate:
         params["birthdate"] = birthdate
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V1}/following_born_today",
         params=params,
         data_type=UsersResponse,
+        access_token=access_token,
     )
 
 
-def get_footprints(self, **params) -> List[Footprint]:
+def get_footprints(self, access_token: str = None, **params) -> List[Footprint]:
     """
 
     Parameters:
@@ -140,23 +204,27 @@ def get_footprints(self, **params) -> List[Footprint]:
         - mode: str = None
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V2}/footprints",
         params=params,
         data_type=FootprintsResponse,
+        access_token=access_token,
     ).footprints
 
 
-def get_fresh_user(self, user_id: int) -> UserResponse:
-    self._check_authorization()
+def get_fresh_user(self, user_id: int, access_token: str = None) -> UserResponse:
+    self._check_authorization(access_token)
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.USERS_V2}/fresh/{user_id}", data_type=UserResponse
+        "GET",
+        endpoint=f"{Endpoints.USERS_V2}/fresh/{user_id}",
+        data_type=UserResponse,
+        access_token=access_token,
     )
 
 
-def get_hima_users(self, **params) -> List[UserWrapper]:
+def get_hima_users(self, access_token: str = None, **params) -> List[UserWrapper]:
     """
 
     Parameters:
@@ -166,12 +234,13 @@ def get_hima_users(self, **params) -> List[UserWrapper]:
         - number: int = None
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V2}/hima_users",
         params=params,
         data_type=HimaUsersResponse,
+        access_token=access_token,
     ).hima_users
 
 
@@ -208,16 +277,21 @@ def get_user_ranking(self, mode: str) -> RankingUsersResponse:
     )
 
 
-def get_refresh_counter_requests(self) -> RefreshCounterRequestsResponse:
-    self._check_authorization()
+def get_refresh_counter_requests(
+    self, access_token: str = None
+) -> RefreshCounterRequestsResponse:
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V1}/reset_counters",
         data_type=RefreshCounterRequestsResponse,
+        access_token=access_token,
     )
 
 
-def get_social_shared_users(self, **params) -> SocialShareUsersResponse:
+def get_social_shared_users(
+    self, access_token: str = None, **params
+) -> SocialShareUsersResponse:
     """
 
     Parameters:
@@ -228,39 +302,47 @@ def get_social_shared_users(self, **params) -> SocialShareUsersResponse:
         - from_id: int - (Optional)
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V2}/social_shared_users",
         params=params,
         data_type=SocialShareUsersResponse,
+        access_token=access_token,
     )
 
 
-def get_timestamp(self) -> UserTimestampResponse:
+def get_timestamp(self, access_token: str = None) -> UserTimestampResponse:
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V2}/timestamp",
         data_type=UserTimestampResponse,
+        access_token=access_token,
     )
 
 
-def get_user(self, user_id: int) -> User:
+def get_user(self, user_id: int, access_token: str = None) -> User:
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.USERS_V2}/{user_id}", data_type=UserResponse
+        "GET",
+        endpoint=f"{Endpoints.USERS_V2}/{user_id}",
+        data_type=UserResponse,
+        access_token=access_token,
     ).user
 
 
-def get_user_email(self, user_id: int) -> str:
-    self._check_authorization()
+def get_user_email(self, user_id: int, access_token: str = None) -> str:
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V2}/fresh/{user_id}",
         data_type=UserEmailResponse,
+        access_token=access_token,
     ).email
 
 
-def get_user_followers(self, user_id: int, **params) -> FollowUsersResponse:
+def get_user_followers(
+    self, user_id: int, access_token: str = None, **params
+) -> FollowUsersResponse:
     """
 
     Parameters:
@@ -277,10 +359,13 @@ def get_user_followers(self, user_id: int, **params) -> FollowUsersResponse:
         endpoint=f"{Endpoints.USERS_V2}/{user_id}/followers",
         params=params,
         data_type=FollowUsersResponse,
+        access_token=access_token,
     )
 
 
-def get_user_followings(self, user_id: int, **params) -> FollowUsersResponse:
+def get_user_followings(
+    self, user_id: int, access_token: str = None, **params
+) -> FollowUsersResponse:
     # @Body @Nullable SearchUsersRequest searchUsersRequest
     """
 
@@ -294,79 +379,143 @@ def get_user_followings(self, user_id: int, **params) -> FollowUsersResponse:
         - number: int - (optional)
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "POST",
         endpoint=f"{Endpoints.USERS_V2}/{user_id}/list_followings",
         params=params,
         data_type=FollowUsersResponse,
+        access_token=access_token,
     )
 
 
-def get_user_from_qr(self, qr: str) -> UserResponse:
+def get_user_from_qr(self, qr: str, access_token: str = None) -> UserResponse:
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.USERS_V1}/qr_codes/{qr}", data_type=UserResponse
+        "GET",
+        endpoint=f"{Endpoints.USERS_V1}/qr_codes/{qr}",
+        data_type=UserResponse,
+        access_token=access_token,
     )
 
 
-def get_user_without_leaving_footprint(self, user_id: int) -> UserResponse:
+def get_user_without_leaving_footprint(
+    self, user_id: int, access_token: str = None
+) -> UserResponse:
     return self._make_request(
-        "GET", endpoint=f"{Endpoints.USERS_V2}/info/{user_id}", data_type=UserResponse
+        "GET",
+        endpoint=f"{Endpoints.USERS_V2}/info/{user_id}",
+        data_type=UserResponse,
+        access_token=access_token,
     )
 
 
-def get_users(self, user_ids: List[int]) -> UsersResponse:
+def get_users(self, user_ids: List[int], access_token: str = None) -> UsersResponse:
     headers = self.session.headers
-    headers["X-Jwt"] = self.get_web_socket_token()
+    headers["X-Jwt"] = self.get_web_socket_token(access_token=access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V1}/list_id",
         params={"user_ids[]": user_ids},
         data_type=UsersResponse,
         headers=headers,
+        access_token=access_token,
     )
 
 
-def reduce_kenta_penalty(self, user_id: int):
-    self._check_authorization()
+def reduce_kenta_penalty(self, user_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     timestamp = int(datetime.now().timestamp())
     response = self._make_request(
         "POST",
-        endpoint=f"{self.host}api/v3/users/{user_id}/reduce_penalty",
+        endpoint=f"{Configs.YAY_API_URL}/api/v3/users/{user_id}/reduce_penalty",
         payload={
-            "uuid": self.uuid,
-            "api_key": self.api_key,
+            "app_version": self.api_version,
             "timestamp": timestamp,
+            "api_key": self.api_key,
             "signed_info": signed_info_calculating(self.device_uuid, timestamp),
             "signed_version": signed_version_calculating(),
+            "uuid": self.uuid,
         },
-        data_type=CreatePostResponse,
+        access_token=access_token,
     )
     self.logger.info("Penalty has been reduced.")
     return response
 
 
-def refresh_counter(self, counter: str):
+def refresh_counter(self, counter: str, access_token: str = None):
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.USERS_V1}/reset_counters",
         payload={"counter": counter},
+        access_token=access_token,
     )
     self.logger.info("Requested counter refresh.")
     return response
 
 
-def remove_user_avatar(self):
+def register_user(
+    self,
+    email: str,
+    email_grant_token: str,
+    password: str,
+    nickname: str,
+    birth_date: str,
+    gender: int = -1,
+    country_code: str = "JP",
+    biography: str = None,
+    prefecture: str = None,
+    profile_icon_filename: str = None,
+    cover_image_filename: str = None,
+    # @Nullable @Part("sns_info") SignUpSnsInfoRequest signUpSnsInfoRequest,
+    en: int = None,
+    vn: int = None,
+) -> CreateUserResponse:
+    timestamp = int(datetime.now().timestamp())
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.USERS_V2}/remove_profile_photo"
+        "POST",
+        endpoint=f"{Endpoints.USERS_V3}/register",
+        payload={
+            "app_version": self.api_version,
+            "timestamp": timestamp,
+            "api_key": self.api_key,
+            "signed_version": signed_version_calculating(),
+            "signed_info": signed_info_calculating(self.device_uuid, timestamp),
+            "uuid": self.uuid,
+            "nickname": nickname,
+            "birth_date": birth_date,
+            "gender": gender,
+            "country_code": country_code,
+            "biography": biography,
+            "prefecture": prefecture,
+            "profile_icon_filename": profile_icon_filename,
+            "cover_image_filename": cover_image_filename,
+            "email": email,
+            "password": password,
+            "email_grant_token": email_grant_token,
+            "en": en,
+            "vn": vn,
+        },
+        data_type=CreateUserResponse,
+    )
+    self.logger.info(f"A new user has been registered. (USER ID: {response.id})")
+    return response
+
+
+def remove_user_avatar(self, access_token: str = None):
+    response = self._make_request(
+        "POST",
+        endpoint=f"{Endpoints.USERS_V2}/remove_profile_photo",
+        access_token=access_token,
     )
     self.logger.info("Profile image has been removed.")
     return response
 
 
-def remove_user_cover(self):
+def remove_user_cover(self, access_token: str = None):
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.USERS_V2}/remove_cover_image"
+        "POST",
+        endpoint=f"{Endpoints.USERS_V2}/remove_cover_image",
+        access_token=access_token,
     )
     self.logger.info("Profile cover image has been removed.")
     return response
@@ -381,8 +530,9 @@ def report_user(
     screenshot_2_filename: str = None,
     screenshot_3_filename: str = None,
     screenshot_4_filename: str = None,
+    access_token: str = None,
 ):
-    self._check_authorization()
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.USERS_V3}/{user_id}/report",
@@ -394,12 +544,15 @@ def report_user(
             "screenshot_3_filename": screenshot_3_filename,
             "screenshot_4_filename": screenshot_4_filename,
         },
+        access_token=access_token,
     )
     self.logger.info(f"Reported the user '{user_id}'")
     return response
 
 
-def reset_password(self, email: str, email_grant_token: str, password: str):
+def reset_password(
+    self, email: str, email_grant_token: str, password: str, access_token: str = None
+):
     response = self._make_request(
         "PUT",
         endpoint=f"{Endpoints.USERS_V1}/reset_password",
@@ -408,12 +561,13 @@ def reset_password(self, email: str, email_grant_token: str, password: str):
             "email_grant_token": email_grant_token,
             "password": password,
         },
+        access_token=access_token,
     )
     self.logger.info("Reset the password.")
     return response
 
 
-def search_lobi_users(self, **params) -> UsersResponse:
+def search_lobi_users(self, access_token: str = None, **params) -> UsersResponse:
     """
 
     Parameters:
@@ -429,10 +583,11 @@ def search_lobi_users(self, **params) -> UsersResponse:
         endpoint=f"{Endpoints.LOBI_FRIENDS_V1}",
         params=params,
         data_type=UsersResponse,
+        access_token=access_token,
     )
 
 
-def search_users(self, **params) -> UsersResponse:
+def search_users(self, access_token: str = None, **params) -> UsersResponse:
     """
 
     Parameters:
@@ -455,10 +610,13 @@ def search_users(self, **params) -> UsersResponse:
         endpoint=f"{Endpoints.USERS_V1}/search",
         params=params,
         data_type=UsersResponse,
+        access_token=access_token,
     )
 
 
-def set_follow_permission_enabled(self, nickname: str, is_private: bool = None):
+def set_follow_permission_enabled(
+    self, nickname: str, is_private: bool = None, access_token: str = None
+):
     timestamp = int(datetime.now().timestamp())
     response = self._make_request(
         "POST",
@@ -472,52 +630,57 @@ def set_follow_permission_enabled(self, nickname: str, is_private: bool = None):
             "signed_info": signed_info_calculating(self.device_uuid, timestamp),
             "signed_version": signed_version_calculating(),
         },
+        access_token=access_token,
     )
     self.logger.info("Follow permission has been enabled.")
     return response
 
 
-def set_setting_follow_recommendation_enabled(self, on: bool):
+def set_setting_follow_recommendation_enabled(self, on: bool, access_token: str = None):
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.USERS_V1}/visible_on_sns_friend_recommendation_setting",
         params={"on": on},
+        access_token=access_token,
     )
     self.logger.info("Follow recommendation has been enabled.")
     return response
 
 
-def take_action_follow_request(self, target_id: int, action: str):
+def take_action_follow_request(
+    self, target_id: int, action: str, access_token: str = None
+):
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.USERS_V2}/{target_id}/follow_request",
         payload={"action": action},
+        access_token=access_token,
     )
     self.logger.info("Took action follow request.")
     return response
 
 
-def turn_on_hima(self):
-    self._check_authorization()
+def turn_on_hima(self, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "GET",
-        endpoint=f"{Endpoints.USERS_V1}/hima",
+        "GET", endpoint=f"{Endpoints.USERS_V1}/hima", access_token=access_token
     )
     self.logger.info("Turned on 'hima now'.")
     return response
 
 
-def unfollow_user(self, user_id: int):
-    self._check_authorization()
+def unfollow_user(self, user_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.USERS_V2}/{user_id}/unfollow",
+        access_token=access_token,
     )
     self.logger.info(f"Unfollowed the user '{user_id}'")
     return response
 
 
-def update_language(self, language: str):
+def update_language(self, language: str, access_token: str = None):
     timestamp = int(datetime.now().timestamp())
     response = self._make_request(
         "POST",
@@ -529,6 +692,7 @@ def update_language(self, language: str):
             "signed_info": signed_info_calculating(self.device_uuid, timestamp),
             "language": language,
         },
+        access_token=access_token,
     )
     self.logger.info("Language has been updated.")
     return response
@@ -544,8 +708,9 @@ def update_user(
     profile_icon_filename: str = None,
     cover_image_filename: str = None,
     username: str = None,
+    access_token: str = None,
 ):
-    self._check_authorization()
+    self._check_authorization(access_token)
     timestamp = int(datetime.now().timestamp())
     response = self._make_request(
         "POST",
@@ -564,6 +729,7 @@ def update_user(
             "timestamp": timestamp,
             "signed_info": signed_info_calculating(self.device_uuid, timestamp),
         },
+        access_token=access_token,
     )
     self.logger.info("User profile has been updated.")
     return response
@@ -572,28 +738,32 @@ def update_user(
 # BlockApi
 
 
-def block_user(self, user_id: int):
-    self._check_authorization()
+def block_user(self, user_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.USERS_V1}/{user_id}/block",
+        access_token=access_token,
     )
     self.logger.info(f"Blocked the user '{user_id}'")
     return response
 
 
-def get_blocked_user_ids(self) -> BlockedUserIdsResponse:
-    self._check_authorization()
+def get_blocked_user_ids(self, access_token: str = None) -> BlockedUserIdsResponse:
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.USERS_V1}/block_ids",
         data_type=BlockedUserIdsResponse,
+        access_token=access_token,
     )
 
 
-def get_blocked_users(self, from_id: int = None) -> BlockedUsersResponse:
+def get_blocked_users(
+    self, from_id: int = None, access_token: str = None
+) -> BlockedUsersResponse:
     # @Body @NotNull SearchUsersRequest searchUsersRequest
-    self._check_authorization()
+    self._check_authorization(access_token)
     params = {}
     if from_id:
         params["from_id"] = from_id
@@ -602,13 +772,16 @@ def get_blocked_users(self, from_id: int = None) -> BlockedUsersResponse:
         endpoint=f"{Endpoints.USERS_V2}/blocked",
         params=params,
         data_type=BlockedUsersResponse,
+        access_token=access_token,
     )
 
 
-def unblock_user(self, user_id: int):
-    self._check_authorization()
+def unblock_user(self, user_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.USERS_V2}/{user_id}/unblock"
+        "POST",
+        endpoint=f"{Endpoints.USERS_V2}/{user_id}/unblock",
+        access_token=access_token,
     )
     self.logger.info(f"Unblocked the user '{user_id}'")
     return response
@@ -617,7 +790,9 @@ def unblock_user(self, user_id: int):
 # HiddenApi
 
 
-def get_hidden_users_list(self, **params: Union[str, int]) -> HiddenResponse:
+def get_hidden_users_list(
+    self, access_token: str = None, **params: Union[str, int]
+) -> HiddenResponse:
     """
 
     Parameters:
@@ -627,30 +802,35 @@ def get_hidden_users_list(self, **params: Union[str, int]) -> HiddenResponse:
         - number: int = None
 
     """
-    self._check_authorization()
+    self._check_authorization(access_token)
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.HIDDEN_V1}/users",
         params=params,
         data_type=HiddenResponse,
+        access_token=access_token,
     )
 
 
-def hide_user(self, user_id: int):
-    self._check_authorization()
+def hide_user(self, user_id: int, access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
-        "POST", endpoint=f"{Endpoints.HIDDEN_V1}/users", payload={"user_id": user_id}
+        "POST",
+        endpoint=f"{Endpoints.HIDDEN_V1}/users",
+        payload={"user_id": user_id},
+        access_token=access_token,
     )
     self.logger.info(f"User '{user_id}' is hidden")
     return response
 
 
-def unhide_users(self, user_ids: List[int]):
-    self._check_authorization()
+def unhide_users(self, user_ids: List[int], access_token: str = None):
+    self._check_authorization(access_token)
     response = self._make_request(
         "DELETE",
         endpoint=f"{Endpoints.HIDDEN_V1}/users",
         params={"user_ids[]": user_ids},
+        access_token=access_token,
     )
     self.logger.info("Unhid users")
     return response
