@@ -1,4 +1,92 @@
-from .models import *
+"""
+MIT License
+
+Copyright (c) 2023-present Qvco, Konn
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+
+from .models import (
+    Activity,
+    BanWord,
+    Bgm,
+    CallGiftHistory,
+    ChatRoom,
+    ChatRoomDraft,
+    Choice,
+    CoinAmount,
+    CoinExpiration,
+    CoinProduct,
+    CoinProductQuota,
+    ConferenceCall,
+    ConferenceCallUserRole,
+    ContactStatus,
+    CreateGroupQuota,
+    TimelineSettings,
+    Error,
+    Footprint,
+    Game,
+    Genre,
+    GifImage,
+    GifImageCategory,
+    Gift,
+    GiftCount,
+    GiftHistory,
+    GiftingAbility,
+    Group,
+    GroupCategory,
+    GroupGiftHistory,
+    GroupUser,
+    HiddenRecommendedPost,
+    Interest,
+    Message,
+    MessageTag,
+    MuteKeyword,
+    PlatformDetails,
+    PopularWord,
+    Post,
+    PostGift,
+    PostTag,
+    PresignedUrl,
+    Promotion,
+    ReceivedGift,
+    RecentSearch,
+    RefreshCounterRequest,
+    Review,
+    SearchCriteria,
+    Setting,
+    Settings,
+    Shareable,
+    SharedUrl,
+    SnsInfo,
+    Sticker,
+    StickerPack,
+    Survey,
+    ThreadInfo,
+    User,
+    UserAuth,
+    UserWrapper,
+    Video,
+    Walkthrough,
+    WalletTransaction,
+)
+from .utils import parse_datetime
 
 
 class ActiveFollowingsResponse:
